import { useQuery } from "@tanstack/react-query";
import CategoryGrid from "@/components/listing/CategoryGrid";
import ListingGrid from "@/components/listing/ListingGrid";
import SearchBar from "@/components/listing/SearchBar";
import { FEATURED_CATEGORIES } from "@/lib/constants";
import { Link } from "wouter";
import { Button } from "@/components/ui/button";

interface Listing {
  id: number;
  title: string;
  description: string;
  price: number;
  location: string;
  isUrgent: boolean;
  createdAt: string;
  primaryImage: string | null;
  userId: number;
}

const Home = () => {
  // Fetch featured listings
  const { 
    data: featuredListingsData, 
    isLoading: isFeaturedLoading 
  } = useQuery<{ listings: Listing[] }>({
    queryKey: ['/api/listings/featured'],
  });
  
  // Fetch recent listings
  const { 
    data: recentListingsData, 
    isLoading: isRecentLoading 
  } = useQuery<{ listings: Listing[]; pagination: any }>({
    queryKey: ['/api/listings', { limit: 8, offset: 0 }],
  });
  
  // Get the listings data or empty arrays if loading
  const featuredListings = featuredListingsData?.listings || [];
  const recentListings = recentListingsData?.listings || [];
  
  return (
    <div className="min-h-screen bg-white">
      {/* Search Section */}
      <SearchBar />
      
      <main className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8 py-8">
        {/* Featured Categories */}
        <CategoryGrid categories={FEATURED_CATEGORIES} />
        
        {/* Featured Listings */}
        <ListingGrid 
          title="Annonces à la une"
          listings={featuredListings}
          viewAllLink="/search"
          loading={isFeaturedLoading}
          emptyMessage="Aucune annonce à la une pour le moment"
        />
        
        {/* Recent Listings */}
        <ListingGrid 
          title="Annonces récentes"
          listings={recentListings}
          loading={isRecentLoading}
          emptyMessage="Aucune annonce récente pour le moment"
          showLoadMore={recentListingsData?.pagination?.hasMore}
          hasMore={recentListingsData?.pagination?.hasMore}
          onLoadMore={() => {}}
        />
        
        {/* App Promotion */}
        <section className="bg-gradient-to-r from-teal-700 to-teal-500 text-white rounded-lg p-8 mb-10 shadow-lg">
          <div className="flex flex-col md:flex-row items-center justify-between">
            <div className="mb-6 md:mb-0 md:mr-6">
              <h2 className="text-2xl font-bold mb-2">Téléchargez l'application GwadaCoco</h2>
              <p className="mb-4">Trouvez des bonnes affaires en Guadeloupe où que vous soyez !</p>
              <div className="flex flex-col sm:flex-row space-y-3 sm:space-y-0 sm:space-x-4">
                <Button variant="outline" className="bg-black text-white border-black hover:bg-black/90">
                  <i className="fab fa-apple text-xl mr-2"></i>
                  <div>
                    <div className="text-xs">Télécharger sur</div>
                    <div className="font-medium">App Store</div>
                  </div>
                </Button>
                <Button variant="outline" className="bg-black text-white border-black hover:bg-black/90">
                  <i className="fab fa-google-play text-xl mr-2"></i>
                  <div>
                    <div className="text-xs">Télécharger sur</div>
                    <div className="font-medium">Google Play</div>
                  </div>
                </Button>
              </div>
            </div>
            <div className="w-40 md:w-auto">
              <div className="rounded-lg bg-teal-600 border-2 border-yellow-300 h-[200px] w-[300px] flex items-center justify-center p-4 shadow-md">
                <div className="text-center">
                  <i className="fas fa-mobile-alt text-yellow-300 text-4xl mb-3"></i>
                  <span className="text-white text-lg font-bold block">Application GwadaCoco</span>
                  <span className="text-yellow-300 text-sm">Disponible bientôt</span>
                </div>
              </div>
            </div>
          </div>
        </section>
      </main>
    </div>
  );
};

export default Home;
